@@ -120,7 +120,7 @@ clock_map_init (ClockMap *this)
         int i;
         ClockMapPrivate *priv = PRIVATE (this);
 
-	GTK_WIDGET_SET_FLAGS (this, GTK_NO_WINDOW);
+        gtk_widget_set_has_window (GTK_WIDGET (this), FALSE);
 
 	priv->last_refresh = 0;
 	priv->width = 0;
@@ -148,29 +148,29 @@ clock_map_finalize (GObject *g_obj)
 	}
 
         if (priv->stock_map_pixbuf) {
-                gdk_pixbuf_unref (priv->stock_map_pixbuf);
+                g_object_unref (priv->stock_map_pixbuf);
                 priv->stock_map_pixbuf = NULL;
         }
 
 	for (i = 0; i < MARKER_NB; i++) {
         	if (priv->location_marker_pixbuf[i]) {
-                	gdk_pixbuf_unref (priv->location_marker_pixbuf[i]);
+                	g_object_unref (priv->location_marker_pixbuf[i]);
                 	priv->location_marker_pixbuf[i] = NULL;
         	}
 	}
 
         if (priv->location_map_pixbuf) {
-                gdk_pixbuf_unref (priv->location_map_pixbuf);
+                g_object_unref (priv->location_map_pixbuf);
                 priv->location_map_pixbuf = NULL;
         }
 
         if (priv->shadow_pixbuf) {
-                gdk_pixbuf_unref (priv->shadow_pixbuf);
+                g_object_unref (priv->shadow_pixbuf);
                 priv->shadow_pixbuf = NULL;
         }
 
         if (priv->shadow_map_pixbuf) {
-                gdk_pixbuf_unref (priv->shadow_map_pixbuf);
+                g_object_unref (priv->shadow_map_pixbuf);
                 priv->shadow_map_pixbuf = NULL;
         }
 
@@ -182,22 +182,25 @@ clock_map_refresh (ClockMap *this)
 {
         ClockMapPrivate *priv = PRIVATE (this);
 	GtkWidget *widget = GTK_WIDGET (this);
+	GtkAllocation allocation;
+
+	gtk_widget_get_allocation (widget, &allocation);
 
         /* Only do something if we have some space allocated.
          * Note that 1x1 is not really some space... */
-        if (widget->allocation.width <= 1 || widget->allocation.height <= 1)
+        if (allocation.width <= 1 || allocation.height <= 1)
                 return;
 
         /* Allocation changed => we reload the map */
-	if (priv->width != widget->allocation.width ||
-	    priv->height != widget->allocation.height) {
+	if (priv->width != allocation.width ||
+	    priv->height != allocation.height) {
                 if (priv->stock_map_pixbuf) {
-                        gdk_pixbuf_unref (priv->stock_map_pixbuf);
+                        g_object_unref (priv->stock_map_pixbuf);
                         priv->stock_map_pixbuf = NULL;
                 }
 
-                priv->width = widget->allocation.width;
-                priv->height = widget->allocation.height;
+                priv->width = allocation.width;
+                priv->height = allocation.height;
         }
 
         if (!priv->stock_map_pixbuf) {
@@ -217,16 +220,22 @@ static gboolean
 clock_map_expose (GtkWidget *this, GdkEventExpose *event)
 {
         ClockMapPrivate *priv = PRIVATE (this);
-	GtkAllocation allocation = this->allocation;
+	GdkWindow *window;
+	GtkStyle *style;
+	GtkAllocation allocation;
 	GdkRectangle region;
         cairo_t *cr;
 
+	window = gtk_widget_get_window (this);
+	style = gtk_widget_get_style (this);
+	gtk_widget_get_allocation (this, &allocation);
+
 	if (!priv->shadow_map_pixbuf) {
                 g_warning ("Needed to refresh the map in expose event.");
 		clock_map_refresh (CLOCK_MAP (this));
         }
 
-        cr = gdk_cairo_create (this->window);
+        cr = gdk_cairo_create (window);
 
 	region.x = allocation.x;
 	region.y = allocation.y;
@@ -234,8 +243,8 @@ clock_map_expose (GtkWidget *this, GdkEventExpose *event)
 	region.height = gdk_pixbuf_get_height (priv->shadow_map_pixbuf);
 
 	gdk_rectangle_intersect (&region, &(event->area), &region);
-	gdk_draw_pixbuf (this->window,
-			 this->style->black_gc,
+	gdk_draw_pixbuf (window,
+			 style->black_gc,
 			 priv->shadow_map_pixbuf,
 			 region.x - allocation.x,
 			 region.y - allocation.y,
@@ -255,9 +264,9 @@ clock_map_expose (GtkWidget *this, GdkEventExpose *event)
 
         cairo_set_source_rgb (
                 cr,
-                this->style->mid [GTK_STATE_ACTIVE].red   / 65535.0,
-                this->style->mid [GTK_STATE_ACTIVE].green / 65535.0,
-                this->style->mid [GTK_STATE_ACTIVE].blue  / 65535.0);
+                style->mid [GTK_STATE_ACTIVE].red   / 65535.0,
+                style->mid [GTK_STATE_ACTIVE].green / 65535.0,
+                style->mid [GTK_STATE_ACTIVE].blue  / 65535.0);
 
         cairo_set_line_width (cr, 1.0);
         cairo_stroke (cr);
@@ -282,8 +291,8 @@ clock_map_size_allocate (GtkWidget *this, GtkAllocation *allocation)
 	if (GTK_WIDGET_CLASS (clock_map_parent_class)->size_allocate)
 		GTK_WIDGET_CLASS (clock_map_parent_class)->size_allocate (this, allocation);
 
-	if (priv->width != this->allocation.width ||
-	    priv->height != this->allocation.height)
+	if (priv->width != allocation->width ||
+	    priv->height != allocation->height)
                 clock_map_refresh (CLOCK_MAP (this));
 }
 
@@ -361,8 +370,8 @@ clock_map_mark (ClockMap *this, gfloat latitude, gfloat longitude, gint mark)
                                       dest_y,
                                       1.0, 1.0, GDK_INTERP_NEAREST, 0xFF);
 
-                gdk_pixbuf_unref (lhs);
-                gdk_pixbuf_unref (rhs);
+                g_object_unref (lhs);
+                g_object_unref (rhs);
         } else if (dest_x + dest_width > width) {
                 /* split into our two pixbufs for the left and right edges */
                 GdkPixbuf *lhs = NULL;
@@ -390,8 +399,8 @@ clock_map_mark (ClockMap *this, gfloat latitude, gfloat longitude, gint mark)
                                       dest_y,
                                       1.0, 1.0, GDK_INTERP_NEAREST, 0xFF);
 
-                gdk_pixbuf_unref (lhs);
-                gdk_pixbuf_unref (rhs);
+                g_object_unref (lhs);
+                g_object_unref (rhs);
         } else {
                 gdk_pixbuf_composite (marker, priv->location_map_pixbuf,
                                       dest_x, dest_y,
@@ -402,17 +411,23 @@ clock_map_mark (ClockMap *this, gfloat latitude, gfloat longitude, gint mark)
         }
 
         if (partial != NULL) {
-                gdk_pixbuf_unref (partial);
+                g_object_unref (partial);
         }
 }
 
-static void
+/**
+ * Return value: %TRUE if @loc can be placed on the map, %FALSE otherwise.
+ **/
+static gboolean
 clock_map_place_location (ClockMap *this, ClockLocation *loc, gboolean hilight)
 {
         gfloat latitude, longitude;
 	gint marker;
 
         clock_location_get_coords (loc, &latitude, &longitude);
+        /* 0/0 means unset, basically */
+        if (latitude == 0 && longitude == 0)
+                return FALSE;
 
 	if (hilight)
 		marker = MARKER_HILIGHT;
@@ -422,6 +437,8 @@ clock_map_place_location (ClockMap *this, ClockLocation *loc, gboolean hilight)
 		marker = MARKER_NORMAL;
 
         clock_map_mark (this, latitude, longitude, marker);
+
+        return TRUE;
 }
 
 static void
@@ -432,7 +449,7 @@ clock_map_place_locations (ClockMap *this)
         ClockLocation *loc;
 
         if (priv->location_map_pixbuf) {
-                gdk_pixbuf_unref (priv->location_map_pixbuf);
+                g_object_unref (priv->location_map_pixbuf);
                 priv->location_map_pixbuf = NULL;
         }
 
@@ -557,7 +574,7 @@ clock_map_render_shadow (ClockMap *this)
         ClockMapPrivate *priv = PRIVATE (this);
 
         if (priv->shadow_pixbuf) {
-                gdk_pixbuf_unref (priv->shadow_pixbuf);
+                g_object_unref (priv->shadow_pixbuf);
         }
 
         priv->shadow_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
@@ -569,7 +586,7 @@ clock_map_render_shadow (ClockMap *this)
         clock_map_render_shadow_pixbuf (priv->shadow_pixbuf);
 
         if (priv->shadow_map_pixbuf) {
-                gdk_pixbuf_unref (priv->shadow_map_pixbuf);
+                g_object_unref (priv->shadow_map_pixbuf);
         }
 
         priv->shadow_map_pixbuf = gdk_pixbuf_copy (priv->location_map_pixbuf);
@@ -604,9 +621,11 @@ highlight (gpointer user_data)
        if (data->count == 6)
                return FALSE;
 
-       if (data->count % 2 == 0)
-                 clock_map_place_location (data->map, data->location, TRUE);
-       else
+       if (data->count % 2 == 0) {
+                 if (!clock_map_place_location (data->map,
+                                                data->location, TRUE))
+                         return FALSE;
+       } else
                  clock_map_place_locations (data->map);
        clock_map_display (data->map);
 
