@@ -25,7 +25,7 @@
 #ifndef __PANEL_ENUMS_H__
 #define __PANEL_ENUMS_H__
 
-#include <glib/gmacros.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
@@ -78,7 +78,7 @@ typedef enum {
 	PANEL_OBJECT_DRAWER,
 	PANEL_OBJECT_MENU,
 	PANEL_OBJECT_LAUNCHER,
-	PANEL_OBJECT_BONOBO,
+	PANEL_OBJECT_APPLET,
 	PANEL_OBJECT_ACTION,
 	PANEL_OBJECT_MENU_BAR,
 	PANEL_OBJECT_SEPARATOR,
