@@ -1,13 +1,20 @@
 #ifndef PANEL_ICON_NAMES_H
 #define PANEL_ICON_NAMES_H
 
-#define PANEL_ICON_BOOKMARKS		"stock_bookmark"
+#define PANEL_ICON_BOOKMARKS		"user-bookmarks"
 #define PANEL_ICON_BURNER		"nautilus-cd-burner"
 #define PANEL_ICON_COMPUTER		"computer"
 #define PANEL_ICON_DESKTOP		"user-desktop"
 #define PANEL_ICON_DRAWER		"gnome-panel-drawer"
 #define PANEL_ICON_FILESYSTEM		"drive-harddisk"
 #define PANEL_ICON_FOLDER		"folder"
+#define PANEL_ICON_FOLDER_DOCUMENTS	"folder-documents"
+#define PANEL_ICON_FOLDER_DOWNLOAD	"folder-download"
+#define PANEL_ICON_FOLDER_MUSIC		"folder-music"
+#define PANEL_ICON_FOLDER_PICTURES	"folder-pictures"
+#define PANEL_ICON_FOLDER_PUBLIC_SHARE	"folder-publicshare"
+#define PANEL_ICON_FOLDER_TEMPLATES	"folder-templates"
+#define PANEL_ICON_FOLDER_VIDEOS	"folder-videos"
 #define PANEL_ICON_FONTS		"preferences-desktop-font"
 #define PANEL_ICON_FORCE_QUIT		"gnome-panel-force-quit"
 #define PANEL_ICON_HOME			"user-home"
@@ -25,7 +32,7 @@
 #define PANEL_ICON_SEPARATOR		"gnome-panel-separator"
 #define PANEL_ICON_SAVED_SEARCH		"folder-saved-search"
 #define PANEL_ICON_SEARCHTOOL		"system-search"
-#define PANEL_ICON_SHUTDOWN		"gnome-shutdown"
+#define PANEL_ICON_SHUTDOWN		"system-shutdown"
 #define PANEL_ICON_THEME		"preferences-desktop-theme"
 #define PANEL_ICON_TRASH		"user-trash"
 #define PANEL_ICON_UNKNOWN		"image-missing"
