@@ -32,6 +32,7 @@
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-glib.h>
 #include <libpanel-util/panel-keyfile.h>
+#include <libpanel-util/panel-xdg.h>
 
 #include "applet.h"
 #include "nothing.h"
@@ -101,10 +102,14 @@ panel_push_window_busy (GtkWidget *window)
 	busy ++;
 
 	if (busy == 1) {
+		GdkWindow *win;
+
 		gtk_widget_set_sensitive (window, FALSE);
-		if (window->window != NULL) {
+
+		win = gtk_widget_get_window (window);
+		if (win != NULL) {
 			GdkCursor *cursor = gdk_cursor_new (GDK_WATCH);
-			gdk_window_set_cursor (window->window, cursor);
+			gdk_window_set_cursor (win, cursor);
 			gdk_cursor_unref (cursor);
 			gdk_flush ();
 		}
@@ -122,9 +127,14 @@ panel_pop_window_busy (GtkWidget *window)
 	busy --;
 
 	if (busy <= 0) {
+		GdkWindow *win;
+
 		gtk_widget_set_sensitive (window, TRUE);
-		if (window->window != NULL)
-			gdk_window_set_cursor (window->window, NULL);
+
+		win = gtk_widget_get_window (window);
+		if (win != NULL)
+			gdk_window_set_cursor (win, NULL);
+
 		g_object_set_data (G_OBJECT (window),
 				   "Panel:WindowBusy", NULL);
 	} else {
@@ -240,24 +250,6 @@ panel_uri_exists (const char *uri)
 	return ret;
 }
 
-char *
-panel_util_icon_remove_extension (const char *icon)
-{
-	char *icon_no_extension;
-	char *p;
-
-	icon_no_extension = g_strdup (icon);
-	p = strrchr (icon_no_extension, '.');
-	if (p &&
-	    (strcmp (p, ".png") == 0 ||
-	     strcmp (p, ".xpm") == 0 ||
-	     strcmp (p, ".svg") == 0)) {
-	    *p = 0;
-	}
-
-	return icon_no_extension;
-}
-
 char *
 panel_find_icon (GtkIconTheme  *icon_theme,
 		 const char    *icon_name,
@@ -287,7 +279,7 @@ panel_find_icon (GtkIconTheme  *icon_theme,
 
 	/* This is needed because some .desktop files have an icon name *and*
 	 * an extension as icon */
-	icon_no_extension = panel_util_icon_remove_extension (icon_name);
+	icon_no_extension = panel_xdg_icon_remove_extension (icon_name);
 
 	info = gtk_icon_theme_lookup_icon (icon_theme, icon_no_extension,
 					   size, 0);
@@ -447,8 +439,16 @@ panel_lock_screen (GdkScreen *screen)
 static char *
 panel_launcher_get_personal_path (void)
 {
-	return g_build_filename (g_get_home_dir (), ".gnome2",
-				 PANEL_LAUNCHER_PERSONAL_PATH, NULL);
+        const char *override;
+
+        override = g_getenv ("GNOME22_USER_DIR");
+
+        if (override)
+               return g_build_filename (override,
+                                        PANEL_LAUNCHER_PERSONAL_PATH, NULL);
+        else
+                return g_build_filename (g_get_home_dir (), ".gnome2",
+                                         PANEL_LAUNCHER_PERSONAL_PATH, NULL);
 }
 
 gboolean
@@ -771,7 +771,7 @@ panel_util_get_gfile_root (GFile *file)
 	return parent_old;
 }
 
-char *
+static char *
 panel_util_get_icon_name_from_g_icon (GIcon *gicon)
 {
 	const char * const *names;
@@ -792,46 +792,6 @@ panel_util_get_icon_name_from_g_icon (GIcon *gicon)
 	return NULL;
 }
 
-GdkPixbuf *
-panel_util_get_pixbuf_from_g_loadable_icon (GIcon *gicon,
-					    int    size)
-{
-	GdkPixbuf    *pixbuf;
-	GInputStream *stream;
-
-	if (!G_IS_LOADABLE_ICON (gicon))
-		return NULL;
-
-	pixbuf = NULL;
-
-	stream = g_loadable_icon_load (G_LOADABLE_ICON (gicon),
-				       size,
-				       NULL, NULL, NULL);
-	if (stream) {
-		pixbuf = gdk_pixbuf_new_from_stream (stream, NULL, NULL);
-		g_object_unref (stream);
-	}
-
-	if (pixbuf) {
-		gint width, height;
-
-		width = gdk_pixbuf_get_width (pixbuf);
-		height = gdk_pixbuf_get_height (pixbuf);
-
-		if (width > size || height > size) {
-			GdkPixbuf *tmp;
-
-			tmp = gdk_pixbuf_scale_simple (pixbuf, size, size,
-						       GDK_INTERP_BILINEAR);
-
-			g_object_unref (pixbuf);
-			pixbuf = tmp;
-		}
-	}
-
-	return pixbuf;
-}
-
 static char *
 panel_util_get_file_display_name_if_mount (GFile *file)
 {
@@ -977,6 +937,7 @@ panel_util_get_file_icon_name_if_mount (GFile *file)
 	return ret;
 }
 
+/* TODO: convert this to a simple call to g_file_query_info? */
 static const char *
 panel_util_get_icon_for_uri_known_folders (const char *uri)
 {
@@ -991,6 +952,10 @@ panel_util_get_icon_for_uri_known_folders (const char *uri)
 
 	path = g_filename_from_uri (uri, NULL, NULL);
 
+	/* Sanity check. We may be given a broken URI. */
+	if (path == NULL)
+		return NULL;
+
 	len = strlen (path);
 	if (path[len] == '/')
 		path[len] = '\0';
@@ -1002,6 +967,27 @@ panel_util_get_icon_for_uri_known_folders (const char *uri)
 	else if (strcmp (path,
 			 g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP)) == 0)
 		icon = PANEL_ICON_DESKTOP;
+	else if (g_strcmp0 (path,
+			    g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS)) == 0)
+		icon = PANEL_ICON_FOLDER_DOCUMENTS;
+	else if (g_strcmp0 (path,
+			    g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD)) == 0)
+		icon = PANEL_ICON_FOLDER_DOWNLOAD;
+	else if (g_strcmp0 (path,
+			    g_get_user_special_dir (G_USER_DIRECTORY_MUSIC)) == 0)
+		icon = PANEL_ICON_FOLDER_MUSIC;
+	else if (g_strcmp0 (path,
+			    g_get_user_special_dir (G_USER_DIRECTORY_PICTURES)) == 0)
+		icon = PANEL_ICON_FOLDER_PICTURES;
+	else if (g_strcmp0 (path,
+			    g_get_user_special_dir (G_USER_DIRECTORY_PUBLIC_SHARE)) == 0)
+		icon = PANEL_ICON_FOLDER_PUBLIC_SHARE;
+	else if (g_strcmp0 (path,
+			    g_get_user_special_dir (G_USER_DIRECTORY_TEMPLATES)) == 0)
+		icon = PANEL_ICON_FOLDER_TEMPLATES;
+	else if (g_strcmp0 (path,
+			    g_get_user_special_dir (G_USER_DIRECTORY_VIDEOS)) == 0)
+		icon = PANEL_ICON_FOLDER_VIDEOS;
 
 	g_free (path);
 
@@ -1093,6 +1079,9 @@ panel_util_get_label_for_uri (const char *text_uri)
 	return label;
 }
 
+/* FIXME: we probably want to return a GIcon, that would be built with
+ * g_themed_icon_new_with_default_fallbacks() since we can get an icon like
+ * "folder-music", where "folder" is the safe fallback. */
 char *
 panel_util_get_icon_for_uri (const char *text_uri)
 {
